<?php

/*
=====================================================
 This ExpressionEngine plugin was created by Laisvunas Sopauskas
 - laisvunas@classicsunlocked.net
 - http://www.classicsunlocked.net/
=====================================================
 This program is freeware; 
 you may use this code for any purpose, commercial or
 private, without any further permission from the author.
=====================================================
 File: pi.category_id.php
-----------------------------------------------------
 Purpose: Find category id. Use found category id as parameter of other tags.
=====================================================
*/

$plugin_info = array(
						'pi_name'			=> 'Category Id',
						'pi_version'		=> '1.4',
						'pi_author'			=> 'Laisvunas Sopauskas',
						'pi_author_url'		=> 'http://www.classicsunlocked.net/',
						'pi_description'	=> 'Allows you to find category id. Use found category id as parameter of other tags.',
						'pi_usage'			=> category_id::usage()

					);

class Category_id {

  var $return_data="";
  
  function Category_id()
  {
    global $IN, $TMPL, $DB, $FNS;
    
    // Fetch the tagdata
		  $tagdata = $TMPL->tagdata;
    
    // Fetch params
    $groupid = $TMPL->fetch_param('category_group');
    $caturltitle = $TMPL->fetch_param('category_url_title');
    $onfailure = $TMPL->fetch_param('on_failure');
    $invalid_input = $TMPL->fetch_param('invalid_input');
    
    // Define variable
    $found_invalid = FALSE;
    $resultstring = '';
    
    // category_group and category_url_title params must be defined
    if ($groupid === FALSE)
    {
      if ($invalid_input === 'alert')
      {
        exit('Error! Parameter "category_group" of exp:category_id tag not defined.');      
      }
      $found_invalid = TRUE;
    }
    elseif ($caturltitle === FALSE)
    {
      if ($invalid_input === 'alert')
      {
      exit('Error! Parameter "category_url_title" of exp:category_id tag not defined.');     
      }
      $found_invalid = TRUE;
    }
    
    // Simple validation of params values
    $invalidchars = array('~', '#', '*', '{', '}', '[', ']', '/', '\\', '<', '>', '\'', '\"', ' ', '|', ':');
    foreach($invalidchars as $char)
    {
      if (strpos($groupid,$char) > 0 OR strpos($groupid,$char) === 0) 
      {
        if ($invalid_input === 'alert')
        {
          exit('Error! Parameter "category_group" of exp:category_id tag contains illegal character.');       
        }
        $found_invalid = TRUE;
      }
    }
    foreach($invalidchars as $char)
    {
      if (strpos($caturltitle,$char) > 0 OR strpos($caturltitle,$char) === 0) 
      {
        if ($invalid_input === 'alert')
        {
          exit('Error! Parameter "category_url_title" of exp:category_id tag contains illegal character.');       
        }
        $found_invalid = TRUE;
      }
    }
    
    if ($found_invalid === FALSE)
    {
      // Create SQL query string
      $todo = "SELECT cat_id FROM exp_categories WHERE group_id = '".$groupid."' AND cat_url_title = '".$caturltitle."' LIMIT 0, 1";
      
      // Perform SQL query
      $query = $DB->query($todo);
      
      // Form result string
      if ($query->num_rows == 1)
      {
        $resultstring = $query->row['cat_id'];
      }
      
      // If on_failure param was defined and needed category id was not found 
      // then on_failure param value will be our resultstring
      if ($onfailure !== FALSE AND $resultstring === '')
      {
        $resultstring = $onfailure;
      }
      
      // Create conditionals array
      $conds['category_id'] = $resultstring;
      
      // Make category_id variable available for use in conditionals
      $tagdata = $FNS->prep_conditionals($tagdata, $conds);

      // Return resultstring as {category_id} variable's output
      $tagdata = str_replace('{category_id}', $resultstring, $tagdata); 
      
      // Output tagdata
      $this->return_data = $tagdata;
    }
  }
  // END FUNCTION
  
// ----------------------------------------
//  Plugin Usage
// ----------------------------------------
// This function describes how the plugin is used.
//  Make sure and use output buffering

function usage()
{
ob_start(); 
?>

PARAMETERS:

1) category_group - (integer starting from 1). Required. Allows you to specify ID number of category group 
(the ID number of each category group is displayed in the Control Panel).

2) category_url_title - (any string which consists from characters legal for use in url segment). Required. 
Allows you to specify URL title of the category. 

3) on_failure - (any string which consists from characters legal for use in ExpressionEngine's tag parameter 
values). Optional. Allows you to specify what {exp:category_id} tag will output in case category group or 
category url title specified in parameters does not exist.

4) invalid_input - Optional. Accepts two values: “alert” and “silence”.
Default value is “silence”. If the value is “alert”, then in cases when some
parameter’s value is invalid plugin exits and PHP alert is being shown;
if the value is “silence”, then in cases when some parameter’s value
is invalid plugin finishes its work without any alert being shown. 
Set this parameter to “alert” for development, and to “silence” - for deployment. 

EXAMPLE OF USAGE:

If URL title of your category is "my_category" and id number of it's category group is "5"  
then the code

{exp:category_id category_group="5" category_url_title="my_category"}
{category_id}
{/exp:category_id}

will return id of the category which belongs to category group 5 and has URL title "my_category". 

You can use output of {category_id} variable 
as parameter of other tag. For such use 
you must add parse="inward" parameter to {exp:category_id} tag.

For example, code as this will work

{exp:category_id category_group="5" category_url_title="{segment_3}" parse="inward"}
{exp:weblog:category_archive weblog="my_weblog" show="{category_id}"}
Some code
{/exp:weblog:category_archive}
{/exp:category_id}

If category group or category url title specified in parameters does not exist then the tag {exp:category_id} 
by default will return nothing. In case 'on_failure' parameter was defined, then, in such case
the tag will output what was specified as value of this parameter.

Conditionals inside {exp:category_id} tag are supported. You can use conditionals to check if
category exists:

{exp:category_id category_group="5" category_url_title="{segment_3}"}
{if category_id!=""}
Some code
{/if}
{/exp:category_id}

Place this tag in any of your templates.

<?php
$buffer = ob_get_contents();
	
ob_end_clean(); 

return $buffer;
}
// END USAGE

}
// END CLASS
?>
